@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: hakyll
-version: 4.7.5.1
-id: hakyll-4.7.5.1-ad3312425ae839ad9e85eef9a1764729
-key: hakyl_6sWjbEMvR5kDaSTa9mo5ud
+version: 4.7.5.2
+id: hakyll-4.7.5.2-e854ee49855603154159fa29193140c8
+key: hakyl_K4KZEhBVf4Y6tHFF4ISafp
 license: BSD3
 maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
 homepage: http://jaspervdj.be/hakyll
@@ -47,10 +47,10 @@ hidden-modules: Hakyll.Check Hakyll.Commands
                 Hakyll.Core.Runtime Hakyll.Core.Store Hakyll.Core.Util.File
                 Hakyll.Core.Util.Parser Hakyll.Web.Pandoc.Binary Paths_hakyll
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/hakyll-4.7.5.1
-library-dirs: /usr/lib/ghc-7.10.3/site-local/hakyll-4.7.5.1
-data-dir: /usr/share/arm-linux-ghc-7.10.3/hakyll-4.7.5.1
-hs-libraries: HShakyll-4.7.5.1-6sWjbEMvR5kDaSTa9mo5ud
+import-dirs: /usr/lib/ghc-7.10.3/site-local/hakyll-4.7.5.2
+library-dirs: /usr/lib/ghc-7.10.3/site-local/hakyll-4.7.5.2
+data-dir: /usr/share/arm-linux-ghc-7.10.3/hakyll-4.7.5.2
+hs-libraries: HShakyll-4.7.5.2-K4KZEhBVf4Y6tHFF4ISafp
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
@@ -59,7 +59,7 @@ depends:
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     cmdargs-0.10.14-ea4d1877c8c5fa6ed8eebd52f962ac3b
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    cryptohash-0.11.7-d9e0f8e58e69d0717d29fde3802983d0
+    cryptohash-0.11.9-66ecf9651f97183101697edd4149971c
     data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
     deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
@@ -70,8 +70,8 @@ depends:
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
     network-uri-2.6.1.0-0e39aca8530572505c01ef548c540bd6
-    pandoc-1.17.0.1-1c6da1ddfcd8a2619fb2ca103a269dd9
-    pandoc-citeproc-0.9.1.1-e33a750d478d5c454d26592c51122195
+    pandoc-1.17.0.3-257df634e15a54e32a712d876ce77ba5
+    pandoc-citeproc-0.9.1.1-26de2ff2cab65872a11f6945922d6e10
     parsec-3.1.9-3365ddffd9ca11d2f0b377e002b54baf
     process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
     random-1.1-41a0a7ecd483c665a5c3a093a5be2968
